ConvEInteraction
================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: ConvEInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ConvEInteraction.tail_entity_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~ConvEInteraction.func

   .. rubric:: Attributes Documentation

   .. autoattribute:: tail_entity_shape

   .. rubric:: Methods Documentation

   .. automethod:: func
